@@ -3,39 +3,38 @@
 from __future__ import print_function, division
 
 from sympy.core import Add, Mul, Symbol, sympify, Dummy, symbols
-from sympy.functions.elementary.miscellaneous import sqrt
+from sympy.core.compatibility import range, string_types
 from sympy.core.singleton import S
-
-from sympy.polys.polytools import Poly, PurePoly
-from sympy.polys.polyutils import _analyze_gens
-
-from sympy.polys.polyclasses import DMP
-
-from sympy.polys.densebasic import (
-    dmp_zero, dmp_one, dmp_ground, dmp_normal,
-    dup_from_raw_dict, dmp_raise, dup_random
-)
-
+from sympy.functions.elementary.miscellaneous import sqrt
+from sympy.ntheory import nextprime
 from sympy.polys.densearith import (
     dmp_add_term, dmp_neg, dmp_mul, dmp_sqr
 )
-
-from sympy.polys.factortools import (
-    dup_zz_cyclotomic_poly
+from sympy.polys.densebasic import (
+    dmp_zero, dmp_one, dmp_ground,
+    dup_from_raw_dict, dmp_raise, dup_random
 )
-
 from sympy.polys.domains import ZZ
-
-from sympy.ntheory import nextprime
-
+from sympy.polys.factortools import dup_zz_cyclotomic_poly
+from sympy.polys.polyclasses import DMP
+from sympy.polys.polytools import Poly, PurePoly
+from sympy.polys.polyutils import _analyze_gens
 from sympy.utilities import subsets, public
 
-from sympy.core.compatibility import xrange
-
 
 @public
-def swinnerton_dyer_poly(n, x=None, **args):
-    """Generates n-th Swinnerton-Dyer polynomial in `x`.  """
+def swinnerton_dyer_poly(n, x=None, polys=False):
+    """Generates n-th Swinnerton-Dyer polynomial in `x`.
+
+    Parameters
+    ----------
+    n : int
+        `n` decides the order of polynomial
+    x : optional
+    polys : bool, optional
+        ``polys=True`` returns an expression, otherwise
+        (default) returns an expression.
+    """
     from .numberfields import minimal_polynomial
     if n <= 0:
         raise ValueError(
@@ -49,10 +48,10 @@ def swinnerton_dyer_poly(n, x=None, **args):
     if n > 3:
         p = 2
         a = [sqrt(2)]
-        for i in xrange(2, n + 1):
+        for i in range(2, n + 1):
             p = nextprime(p)
             a.append(sqrt(p))
-        return minimal_polynomial(Add(*a), x, polys=args.get('polys', False))
+        return minimal_polynomial(Add(*a), x, polys=polys)
 
     if n == 1:
         ex = x**2 - 2
@@ -60,14 +59,23 @@ def swinnerton_dyer_poly(n, x=None, **args):
         ex = x**4 - 10*x**2 + 1
     elif n == 3:
         ex = x**8 - 40*x**6 + 352*x**4 - 960*x**2 + 576
-    if not args.get('polys', False):
-        return ex
-    else:
-        return PurePoly(ex, x)
+
+    return PurePoly(ex, x) if polys else ex
+
 
 @public
-def cyclotomic_poly(n, x=None, **args):
-    """Generates cyclotomic polynomial of order `n` in `x`. """
+def cyclotomic_poly(n, x=None, polys=False):
+    """Generates cyclotomic polynomial of order `n` in `x`.
+
+    Parameters
+    ----------
+    n : int
+        `n` decides the order of polynomial
+    x : optional
+    polys : bool, optional
+        ``polys=True`` returns an expression, otherwise
+        (default) returns an expression.
+    """
     if n <= 0:
         raise ValueError(
             "can't generate cyclotomic polynomial of order %s" % n)
@@ -79,15 +87,17 @@ def cyclotomic_poly(n, x=None, **args):
     else:
         poly = PurePoly.new(poly, Dummy('x'))
 
-    if not args.get('polys', False):
-        return poly.as_expr()
-    else:
-        return poly
+    return poly if polys else poly.as_expr()
 
 
 @public
 def symmetric_poly(n, *gens, **args):
-    """Generates symmetric polynomial of order `n`. """
+    """Generates symmetric polynomial of order `n`.
+
+    Returns a Poly object when ``polys=True``, otherwise
+    (default) returns an expression.
+    """
+    # TODO: use an explicit keyword argument when Python 2 support is dropped
     gens = _analyze_gens(gens)
 
     if n < 0 or n > len(gens) or not gens:
@@ -95,7 +105,7 @@ def symmetric_poly(n, *gens, **args):
     elif not n:
         poly = S.One
     else:
-        poly = Add(*[ Mul(*s) for s in subsets(gens, int(n)) ])
+        poly = Add(*[Mul(*s) for s in subsets(gens, int(n))])
 
     if not args.get('polys', False):
         return poly
@@ -105,53 +115,59 @@ def symmetric_poly(n, *gens, **args):
 
 @public
 def random_poly(x, n, inf, sup, domain=ZZ, polys=False):
-    """Return a polynomial of degree ``n`` with coefficients in ``[inf, sup]``. """
+    """Generates a polynomial of degree ``n`` with coefficients in
+    ``[inf, sup]``.
+
+    Parameters
+    ----------
+    x
+        `x` is the independent term of polynomial
+    n : int
+        `n` decides the order of polynomial
+    inf
+        Lower limit of range in which coefficients lie
+    sup
+        Upper limit of range in which coefficients lie
+    domain : optional
+         Decides what ring the coefficients are supposed
+         to belong. Default is set to Integers.
+    polys : bool, optional
+        ``polys=True`` returns an expression, otherwise
+        (default) returns an expression.
+    """
     poly = Poly(dup_random(n, inf, sup, domain), x, domain=domain)
 
-    if not polys:
-        return poly.as_expr()
-    else:
-        return poly
+    return poly if polys else poly.as_expr()
 
 
 @public
 def interpolating_poly(n, x, X='x', Y='y'):
     """Construct Lagrange interpolating polynomial for ``n`` data points. """
-    if isinstance(X, str):
+    if isinstance(X, string_types):
         X = symbols("%s:%s" % (X, n))
 
-    if isinstance(Y, str):
+    if isinstance(Y, string_types):
         Y = symbols("%s:%s" % (Y, n))
 
     coeffs = []
+    numert = Mul(*[(x - u) for u in X])
 
-    for i in xrange(0, n):
-        numer = []
-        denom = []
-
-        for j in xrange(0, n):
-            if i == j:
-                continue
-
-            numer.append(x - X[j])
-            denom.append(X[i] - X[j])
-
-        numer = Mul(*numer)
-        denom = Mul(*denom)
-
+    for i in range(n):
+        numer = numert/(x - X[i])
+        denom = Mul(*[(X[i] - X[j]) for j in range(n) if i != j])
         coeffs.append(numer/denom)
 
-    return Add(*[ coeff*y for coeff, y in zip(coeffs, Y) ])
+    return Add(*[coeff*y for coeff, y in zip(coeffs, Y)])
 
 
 def fateman_poly_F_1(n):
     """Fateman's GCD benchmark: trivial GCD """
-    Y = [ Symbol('y_' + str(i)) for i in xrange(0, n + 1) ]
+    Y = [Symbol('y_' + str(i)) for i in range(n + 1)]
 
     y_0, y_1 = Y[0], Y[1]
 
-    u = y_0 + Add(*[ y for y in Y[1:] ])
-    v = y_0**2 + Add(*[ y**2 for y in Y[1:] ])
+    u = y_0 + Add(*[y for y in Y[1:]])
+    v = y_0**2 + Add(*[y**2 for y in Y[1:]])
 
     F = ((u + 1)*(u + 2)).as_poly(*Y)
     G = ((v + 1)*(-3*y_1*y_0**2 + y_1**2 - 1)).as_poly(*Y)
@@ -165,12 +181,12 @@ def dmp_fateman_poly_F_1(n, K):
     """Fateman's GCD benchmark: trivial GCD """
     u = [K(1), K(0)]
 
-    for i in xrange(0, n):
+    for i in range(n):
         u = [dmp_one(i, K), u]
 
     v = [K(1), K(0), K(0)]
 
-    for i in xrange(0, n):
+    for i in range(0, n):
         v = [dmp_one(i, K), dmp_zero(i), v]
 
     m = n - 1
@@ -193,11 +209,11 @@ def dmp_fateman_poly_F_1(n, K):
 
 def fateman_poly_F_2(n):
     """Fateman's GCD benchmark: linearly dense quartic inputs """
-    Y = [ Symbol('y_' + str(i)) for i in xrange(0, n + 1) ]
+    Y = [Symbol('y_' + str(i)) for i in range(n + 1)]
 
     y_0 = Y[0]
 
-    u = Add(*[ y for y in Y[1:] ])
+    u = Add(*[y for y in Y[1:]])
 
     H = Poly((y_0 + u + 1)**2, *Y)
 
@@ -211,7 +227,7 @@ def dmp_fateman_poly_F_2(n, K):
     """Fateman's GCD benchmark: linearly dense quartic inputs """
     u = [K(1), K(0)]
 
-    for i in xrange(0, n - 1):
+    for i in range(n - 1):
         u = [dmp_one(i, K), u]
 
     m = n - 1
@@ -230,11 +246,11 @@ def dmp_fateman_poly_F_2(n, K):
 
 def fateman_poly_F_3(n):
     """Fateman's GCD benchmark: sparse inputs (deg f ~ vars f) """
-    Y = [ Symbol('y_' + str(i)) for i in xrange(0, n + 1) ]
+    Y = [Symbol('y_' + str(i)) for i in range(n + 1)]
 
     y_0 = Y[0]
 
-    u = Add(*[ y**(n + 1) for y in Y[1:] ])
+    u = Add(*[y**(n + 1) for y in Y[1:]])
 
     H = Poly((y_0**(n + 1) + u + 1)**2, *Y)
 
@@ -248,7 +264,7 @@ def dmp_fateman_poly_F_3(n, K):
     """Fateman's GCD benchmark: sparse inputs (deg f ~ vars f) """
     u = dup_from_raw_dict({n + 1: K.one}, K)
 
-    for i in xrange(0, n - 1):
+    for i in range(0, n - 1):
         u = dmp_add_term([u], dmp_one(i, K), n + 1, i + 1, K)
 
     v = dmp_add_term(u, dmp_ground(K(2), n - 2), 0, n, K)
